<?php

  class mw_config_actions_logs extends mw_controller{

    public function index(){
      $env = $this->env();
      $env->run("config/actions_logs/historique");
    }

    public function historique(){
      $env = $this->env();
      $env->set_config(array("max_list" => 20));
      $data = $env->data();
      if(
        (
          $historique = $data->list_actions_logs(
            array(
              "index_name" => "id",
              "order_by" => "date_log",
              "order" => "DESC",
              "offset" => isset($_GET[$env->param("start")]) ? $_GET[$env->param("start")] : 0,
              "limit" => $env->config("max_list") ? $env->config("max_list") : null
            )
          )
        ) === false
      ){
        $env->erreur("impossible de lire l'historique des logs");
        return;
      }
      foreach($historique["list"] as $id_log => $log){
        $historique["list"][$id_log]["get"] = $log["get"] ? @unserialize($log["get"]) : false;
        $historique["list"][$id_log]["post"] = $log["post"] ? @unserialize($log["post"]) : false;
      }
      $env->set_out("historique", $historique);
    }

    public function del_historique(){
      $env = $this->env();
      $data = $env->data();
      if(!$data->clear_actions_logs()){
        $env->erreur("impossible de vider l'historique");
        return;
      }
      $env->redirect(
        $env->url("config/actions_logs/historique"),
        "l'historique a été vidé"
      );
    }

    public function config(){
      $env = $this->env();
      $data = $env->data();
      if(($actions_logs_config = $data->get_actions_logs_config()) === false){
        $env->erreur("impossible de lire la configuration");
        return;
      }
      if($_POST){
        $actions_logs_config["do_log"] = isset($_POST["do_log"]) ? true : false;
        $actions_logs_config["default_log"] = ($_POST["default_log"] == "1") ? true : false;
        $actions_logs_config["default_log_get"] = isset($_POST["default_log_get"]) ? true : false;
        $actions_logs_config["default_log_post"] = isset($_POST["default_log_post"]) ? true : false;
        if(!$data->set_actions_logs_config($actions_logs_config)){
          $env->erreur("erreur lors de la mise à jour de la configuration");
          return;
        }
        $env->redirect(
          $env->url("config/actions_logs/config"),
          "la configuration a été mise à jour"
        );
      }
      $env->set_out("actions_logs_config", $actions_logs_config);
    }

    public function logs_actions(){
      $env = $this->env();
      $data = $env->data();
      if(($actions_logs_config = $data->get_actions_logs_config()) === false){
        $env->erreur("impossible de lire la configuration");
        return;
      }
      if(($logs_actions = $data->list_logs_actions(array("index_name" => "id", "order_by" => "action"))) === false){
        $env->erreur("impossible de lire la table #--logs_actions");
        return;
      }
      if($_POST){
        foreach($_POST as $key => $value){
          if(substr($key, 0, 14) == "id_log_action_"){
            $id_log_action = $value;
            $log_action = array(
              "log_get" => isset($_POST["log_get_".$id_log_action]) ? 1 : 0,
              "log_post" => isset($_POST["log_post_".$id_log_action]) ? 1 : 0
            );
            if(!$data->set_logs_actions("id", $id_log_action, $log_action)){
              $env->erreur("erreur lors de l'enregistrement des informations pour les actions");
              return;
            }
          }
        }
        $env->redirect(
          $env->url("config/actions_logs/logs_actions"),
          "Les informations ont été enregistrées"
        );
      }
      $env->set_out("actions_logs_config", $actions_logs_config);
      $env->set_out("logs_actions", $logs_actions);
    }

    public function add_log_action(){
      $env = $this->env();
      $data = $env->data();
      if(($actions_logs_config = $data->get_actions_logs_config()) === false){
        $env->erreur("impossible de lire la configuration");
        return;
      }
      $log_action = array(
        "action" => "",
        "log_get" => false,
        "log_post" => false
      );
      if($_POST){
        if($_POST["action"]){
          if($etat = $env->valid_etat($_POST["action"])){
            $action = $etat["mod"]."/".$etat["controller"]."/".$etat["action"];
            if(($exists = $data->get_logs_actions("action", $action)) === false){
              $env->erreur("impossible de savoir si cette action est déjà dans la liste");
              return;
            }
            if($exists) $env->message("l'action ".$action." est déjà dans la liste");
            $log_action["action"] = $action;
          }
          else $env->message("format d'action invalide");
        }
        else $env->message("merci de préciser une action");
        $log_action["log_get"] = isset($_POST["log_get"]) ? true : false;
        $log_action["log_post"] = isset($_POST["log_post"]) ? true : false;
        if(!$env->messages()){
          if($data->add_logs_actions($log_action)){
            $env->redirect(
              $env->url("config/actions_logs/logs_actions"),
              "L'action a été ajoutée dans la liste"
            );
          }
          else{
            $env->erreur("impossible d'ajouter l'action dans la liste");
            return;
          }
        }
      }
      $env->set_out("actions_logs_config", $actions_logs_config);
      $env->set_out("log_action", $log_action);
    }

    public function del_log_action(){
      $env = $this->env();
      $data = $env->data();
      if(!($log_action = $data->get_logs_actions("id", $_GET[$env->param("id")]))){
        $env->erreur("impossible de lire les informations de cette action dans la liste");
        return;
      }
      if(!$data->del_logs_actions("id", $log_action["id"])){
        $env->erreur("impossible d'effacer cette action de la liste");
        return;
      }
      $env->redirect(
        $env->url("config/actions_logs/logs_actions"),
        "l'action a été retirée de la liste"
      );
    }

    public function del_logs_actions(){
      $env = $this->env();
      $data = $env->data();
      if(!$data->clear_logs_actions()){
        $env->erreur("impossible de vider la liste");
        return;
      }
      $env->redirect(
        $env->url("config/actions_logs/logs_actions"),
        "la liste a été vidée"
      );
    }

  }
